/*
/////////////
/// GetDP ///
/////////////

// File: magnetostaticProblem.pro
// AUTHOR: Frederic Trillaud <ftrillaudp@gmail.com>
// UNIVERSITY: UNAM
// INSTITUTE: IINGEN
// DATE (english): 01/10/2013
// UNITS: SI otherwise indicated

// INTRODUCTION: Model to be sused for resolution.

Inputs:
-------

GlobalGroup:
magneticSolutionDomain -> Whole magnetic domain to be resolved
inductorDomain -> Conductor regions

Function:
nu[] -> magnetic reluctivity

Constraint:
dirichletBoundaryCondition -> Fixed magnetic vector potential (classical boundary conditions in 2D)
currentDensityCondition -> Fixed current density corresponding to the source (depends on direction)
*/


///////////////
/// REGIONS ///
///////////////

Group
{
 DefineGroup[magneticSolutionDomain, inductorDomain];
}

Function
{
 DefineFunction[nu];
}


//////////////////////
/// FUNCTION SPACE ///
//////////////////////

FunctionSpace
{
 { // Potential vector
  Name potential_function_space;
  Type Form1P;
  BasisFunction
  {
   {
    Name phi_node;
    NameOfCoef a_node;
    Function BF_PerpendicularEdge;
    Support magneticSolutionDomain;
    Entity NodesOf[All];
   }
  }
  Constraint
  {
   {
    NameOfCoef a_node;
    EntityType NodesOf;
    NameOfConstraint dirichletBoundaryCondition;
   }
  }
 }
 { // Source current density, Je (fully fixed space)
  Name source_function_space;
  Type Vector;
  BasisFunction
  {
   {
    Name sr;
    NameOfCoef jsr;
    Function BF_RegionZ;
    Support inductorDomain;
    Entity inductorDomain;
   }
  }
  Constraint
  {
   {
    NameOfCoef jsr;
    EntityType Region;
    NameOfConstraint currentDensityCondition;
   }
  }
 }
}


///////////////////
/// FORMULATION ///
///////////////////

Formulation
{
 {
  Name potentialVectorFormulation;
  Type FemEquation;
  Quantity
  {
   {
    Name A;
    Type Local;
    NameOfSpace potential_function_space;
   }
   {
    Name Je;
    Type Local;
    NameOfSpace source_function_space;
   }
  }
  Equation
  {
   Galerkin // magnetic solution domain (entire domain)
   {
    [nu[]*Dof{d A}, {d A}]; // d in both 2D and 3D ==> Grad in 2D and Curl in 3D
    In magneticSolutionDomain;
    Jacobian jacobianVolumeRegion;
    Integration basicIntegration;
   }
   Galerkin // Inductor domain (conductors)
   {
    [-Dof{Je} , {A}];
    In inductorDomain;
    Jacobian jacobianVolumeRegion;
    Integration basicIntegration;
   }
  }
 }
}


//////////////////
/// RESOLUTION ///
//////////////////

Resolution
{
 {
  Name potentialVectorResolution; // to be called: getdp main -msh solenoid2D.msh -solve potentialVectorResolution
  System
  {
   {
    Name potentialVector;
    NameOfFormulation potentialVectorFormulation;
   }
  }
  Operation
  {
//   InitSolution[potentialVector];
   Generate[potentialVector];
   Solve[potentialVector];
   SaveSolution[potentialVector];
  }
 }
}


//////////////////////
/// POSTPROCESSING ///
//////////////////////

PostProcessing
{
 {
  Name postProcessing;
  NameOfFormulation potentialVectorFormulation;
  Quantity
  {
   {Name A; Value{Local{[{A}]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;}}}
   {Name Az; Value{Local{[CompZ[{A}]]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;}}}
   {Name H; Value{Local{[nu[]*{d A}]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;}}}
   {Name B; Value{Local{[{d A}]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;}}}
   {Name Bmod; Value{Local{[Norm[{d A}]]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;}}}
   {Name J; Value{Local{[{Je}] ; In inductorDomain; Jacobian jacobianVolumeRegion;}}}
  }
 }
}


