/*
/////////////
/// GetDP ///
/////////////

// File: main.pro
// AUTHOR: Frederic Trillaud <ftrillaudp@gmail.com>
// UNIVERSITY: UNAM
// INSTITUTE: IINGEN
// DATE (english): 05/02/2013
// UNITS: SI otherwise indicated

// INTRODUCTION: 2D magnetostatic model of a corss-sectiona area of a solenoidal magnet. The resolution is performed based on a 2D magnetstatic potential vector method.

// Computation: getdp main -msh solenoid2D.msh -solve potentialVectorResolution
// Postprocessing: getdp main -msh solenoid2D.msh -pos fieldMap
*/


///////////////////////////
/// EXTERNAL PARAMETERS ///
///////////////////////////

Include "./solenoid2D.par";


///////////////
/// REGIONS ///
///////////////

Group
{
// Name of regions:
spaceRegion = Region[spaceID];
infiniteBoundaryRegion = Region[infiniteBoundaryID]; 
inductorRegion = Region[inductorID];
boundaryLineRegion = Region[boundaryLineID];

// Domains (groups of regions):
inductorDomain = Region[{inductorRegion}];
paramagneticDomain = Region[{spaceRegion, infiniteBoundaryRegion, inductorRegion}];
magneticSolutionDomain = Region[{paramagneticDomain}];
infiniteBoundaryDomain = Region[{infiniteBoundaryRegion}];
boundaryLineDomain = Region[{boundaryLineRegion}];
}

Function
{
// Permeability of vacuum:
muVacuum = 4*Pi*1e-7;
nu[Region[{paramagneticDomain}]] = 1./muVacuum;
// Permeability of core: 
// Current density
crossSection = width_inductor*height_inductor;
fillingFactor = 0.8; // It = Juniform*Amodel = Jreal*Areal so Jreal = (Amodel/Areal)*Juniform with f = (Areal/Amodel), filling factor.
It = 1000;
j_uniform = It/(fillingFactor*crossSection); // crossSection = Amodel
}

Constraint
{
 {
  Name dirichletBoundaryCondition;
  Type Assign;
  Case
  {
   {
    Region boundaryLineDomain;
    Value 0.;
   }
  }
 }
 {
  Name currentDensityCondition;
  Case
  {
   {
    Region inductorDomain;
    Value j_uniform;
   }
  }
 }
}


///////////////
/// METHODS ///
///////////////

// Including external files defining the models to be used
Include "./jacobianMethod.pro";
Include "./integrationMethod.pro";
Include "./magnetostaticProblem.pro";


//////////////////////
/// POSTPROCESSING ///
//////////////////////

PostOperation
{
 {
  Name fieldMap; // to be called: getdp main -msh solenoid2D.msh -pos fileMap
  NameOfPostProcessing postProcessing;
  Operation
  {
   Print[A, OnElementsOf magneticSolutionDomain, File "./potentialVector.pos"];
   Print[B, OnElementsOf magneticSolutionDomain, File "./magneticFluxDensity.pos"];
   Print[Bmod, OnElementsOf magneticSolutionDomain, File "./moduleOfMagneticFluxDensity.pos"];
   Print[H, OnElementsOf magneticSolutionDomain, File "./magneticField.pos"];
   Print[J, OnElementsOf magneticSolutionDomain, File "./currentDensity.pos"];
  }
 }
}


