/////////////////////
/// GMSH GEOMETRY ///
/////////////////////

/// FILE: solenoid2D.geo
/// AUTHOR: Frederic Trillaud <ftrillaudp@gmail.com>
/// UNIVERSITY: UNAM
/// INSTITUTE: IINGEN
/// DATE (english): 02/02/2013
/// UNITS: SI otherwise indicated

/// INTRODUCTION: automatic generation of the geometry to be meshed. Case of the simulation of a solenoid magnet using axial symmetry.

/// The mesh is generated from the graphical interface or the command prompt, taken parameters from the geometry file (see manual):
// > gmsh solenoid2D.geo -2 -o solenoid2D.msh
// -2: 2D mesh
// -o: output to "solenoid2D.msh" file


//////////////////////
/// INCLUDED FILES ///
//////////////////////

/// Include parameter file to define parameters of the geometry ///
Include "./solenoid2D.par";


////////////////
/// MESHING ///
///////////////

/// Renove duplicate nodes of the mesh ///
Coherence Mesh;

/// To copy all the properties of the geometries during transformation for meshing ///
Geometry.CopyMeshingMethod = 1;

/// list of target element size (see parameter file) ///
n[] = {n0, n1_1, n2_1, n3_1, n4_1, n5_1, n6_1, n1_2, n2_2, n3_2, n4_2, n5_2, n1_b, n2_b, n3_b};


//////////////////
/// GEOMETRIES ///
//////////////////

/// Origin ///
x000 = 0; y000 = 0; z000 = 0;

/// Coordinates ///
/// Inductor
x1_1 = distance_axe_symmetry_inductor; y1_1 = 0.;
x2_1 = distance_axe_symmetry_inductor; y2_1 = (-1)*0.5*height_inductor;
x3_1 = distance_axe_symmetry_inductor+width_inductor; y3_1 = (-1)*0.5*height_inductor;
x4_1 = distance_axe_symmetry_inductor+width_inductor; y4_1 = 0.;
x5_1 = distance_axe_symmetry_inductor+width_inductor; y5_1 = 0.5*height_inductor;
x6_1 = distance_axe_symmetry_inductor; y6_1 = 0.5*height_inductor;
/// Space: air or vacuum
x1_2 = 0.; y1_2 = (-1)*subdiscretization_length_space;
x2_2 = 0.; y2_2 = (-1)*radius_space;
x3_2 = radius_space; y3_2 = 0.;
x4_2 = 0.; y4_2 = radius_space;
x5_2 = 0.; y5_2 = subdiscretization_length_space;
/// Outer boundary space: air or vacuum
x1_b = 0.; y1_b = (-1)*radius_outer_space;
x2_b = radius_outer_space; y2_b = 0.;
x3_b = 0.; y3_b = radius_outer_space;
/// List of coordinates
x[] = {x000, x1_1, x2_1, x3_1, x4_1, x5_1, x6_1, x1_2, x2_2, x3_2, x4_2, x5_2, x1_b, x2_b, x3_b};
y[] = {y000, y1_1, y2_1, y3_1, y4_1, y5_1, y6_1, y1_2, y2_2, y3_2, y4_2, y5_2, y1_b, y2_b, y3_b};
z = 0.; // 2D geometry

/// Origin ///
Point(0) = {x[0], y[0], z000, n[0]};

/// Inductor ///
For i In {1:6}
 Point(i) = {x[i], y[i], z, n[i]};
EndFor
For i In {1:5}
Line(i) = {i, i+1};
EndFor
Line(6) = {6, 1};
For i In {1:6}
 listInductor[] += {i};
EndFor
Line Loop(1) = listInductor[];

/// Space ///
For i In {7:11}
 Point(i) = {x[i], y[i], z, n[i]};
EndFor
Line(7) = {0, 7};
Line(8) = {7, 8};
Circle(9) = {8, 0, 9};
Circle(10) = {9, 0, 10};
Line(11) = {10, 11};
Line(12) = {11, 0};
For i In {7:12}
 listSpace[] += {i};
EndFor
Line Loop(2) = listSpace[];

/// Outer boundary space ///
For i In {12:14}
 Point(i) = {x[i], y[i], z, n[i]};
EndFor
Line(13) = {8, 12};
Circle(14) = {12, 0, 13};
Circle(15) = {13, 0, 14};
Line(16) = {14, 10};
Line Loop(3) = {13, 14, 15, 16, -10, -9};
Line Loop(lineLoopBoundary) = {7, 8, 13, 14, 15, 16, 11, 12};

linesBoundary[]={7, 8, 13, 14, 15, 16, 11, 12};

/// Plane surfaces ///
/// Inductor
Plane Surface(1) = {1};
/// Space
Plane Surface(2) = {2, 1};
/// Infinite boundary space
Plane Surface(3) = {3};


///////////////////////
/// PHYSICAL GROUPS ///
///////////////////////
/// NB: define groups of similar properties or to be considered as one by the solver

/// Inductor ///
Physical Surface(inductorID) = {1};
/// Space: air or vacuum ///
Physical Surface(spaceID) = {2};
/// Infinite boundary space: air or vacuum ///
Physical Surface(infiniteBoundaryID) = {3};
/// Boundary line in 2D ///
Physical Line(boundaryLineID) = linesBoundary[];

